#
# spec file for package limesuite
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 23_11-0
%define libname libLimeSuite%{sover}
%define soapy_modver 0.8
Name:           limesuite
Version:        23.11.0
Release:        1.10
Summary:        Collection of software supporting LMS7-based hardware
License:        Apache-2.0
Group:          Productivity/Hamradio/Other
URL:            https://myriadrf.org/projects/lime-suite/
#Git-Clone:     https://github.com/myriadrf/LimeSuite.git
Source:         https://github.com/myriadrf/LimeSuite/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM limesuite-add-missing-includes.patch -- Add missing include
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gnuplot
BuildRequires:  pkgconfig
BuildRequires:  wxGTK3-devel
BuildRequires:  pkgconfig(SoapySDR) >= %{soapy_modver}
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Lime Suite is a collection of software supporting several hardware
platforms including the LimeSDR, drivers for the LMS7002M transceiver
RFIC, and other tools for developing with LMS7-based hardware. Lime
Suite enables many SDR applications, such as GQRX for example, to
work with supported hardware through the bundled SoapySDR support
module.

%package -n %{libname}
Summary:        Library for Lime Suite
Group:          System/Libraries
Requires:       %{name}-udev

%description -n %{libname}
Lime Suite is a collection of software supporting several hardware
platforms and other tools for developing with LMS7-based hardware.

%package udev
Summary:        Udev rules for LimeSDR
Group:          Hardware/Other
BuildArch:      noarch

%description udev
Udev rules for Lime Suite

%package devel
Summary:        Development files for libLimeSuite
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Libraries and header files for developing applications that want to make
use of libLimeSuite.

%package -n soapysdr%{soapy_modver}-module-lms7
Summary:        SoapySDR LMS7 support module
Group:          System/Libraries

%description -n soapysdr%{soapy_modver}-module-lms7
Soapy LMS7 - LimeSDR device support for Soapy SDR.
A Soapy module that supports LimeSDR devices within the Soapy API.

%prep
%setup -q -n LimeSuite-%{version}

# HACK: set udev permissions to 666
sed -i 's|MODE="660"|MODE="666"|g' udev-rules/64-limesuite.rules

%build
%cmake \
  -DBUILD_SHARED_LIBS=ON \
  -DCMAKE_AUTOSET_INSTALL_RPATH=FALSE \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
%ifarch x86_64
  -DENABLE_SIMD_FLAGS="SSE3" \
%else
  -DENABLE_SIMD_FLAGS="none" \
%endif
  -DLIME_SUITE_EXTVER=release
%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n %{libname}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license COPYING
%doc Changelog.txt README.md
%{_bindir}/LimeUtil
%{_bindir}/LimeSuiteGUI
%{_bindir}/LimeQuickTest
%dir %{_datadir}/Lime
%{_datadir}/Lime/Desktop

%files udev
%{_udevrulesdir}/64-limesuite.rules

%files -n %{libname}
%{_libdir}/libLimeSuite.so.*

%files devel
%{_libdir}/libLimeSuite.so
%{_includedir}/lime
%{_libdir}/pkgconfig/LimeSuite.pc
%{_libdir}/cmake/LimeSuite/

%files -n soapysdr%{soapy_modver}-module-lms7
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libLMS7Support.so

%changelog
* Wed Nov 22 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 23.11.0
  * Fix debian packaging dependencies
  * No functional changes
* Sun Oct 29 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 23.10.0
  * API version info in src/VersionInfo.h
  * SoapyLMS7: added reference clock and clock source functions
  * Fix usage of -march=native compile flag
  * Fix hard-to-read log text on dark mode themes
  * Fix OpenGL graph on Retina displays
  * GCC and MSVC warning fixes
  * Fix CMAKE_AUTOSET_INSTALL_RPATH option
- Patch limesuite-add-missing-includes.patch removed (applied
  upstream)
* Tue Apr 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add limesuite-add-missing-includes.patch: Add missing include,
  exposed by gcc 13.
- Use autopatch, cmake_build and ldconfig_scriptlets macros.
- Build udev sub-package as noarch.
* Tue Oct 25 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 22.09.1
  * correct API version info in src/VersionInfo.h
* Thu Sep  8 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 22.09.0
  * Fix FFTviewer crash when forwarding X11 over SSH
  * Add LimeSDR-mini-v2 support
  * Workaround crash with libusb-1.0.25
  * Fix wxWidgets assertions, GUI sizers and alignments
* Mon Jul 12 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Fri Oct 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.10.0
  LimeSuite library changes:
  * Fixed GFIR floating point comparison.
  * Disabled caller-saves optimization for GCC versions 9.3 onwards
  * Changed USB processing, FIFO and remote thread priorities.
  * Fixed null pointer dereferences in StreamChannel write/read
    functions.
  * Added option to configure data link format from API.
  * TDD mode registers are reset after initialization on
    LimeSDR-Core boards.
  * Changed default Common Control Signal value for most boards.
  * Changed LMS_Init to tune SXR/SXT PLL's.
  * Changed LMS_Init to calibrate Tx frontend IAMP gain.
  * Updated SXR/SXT MCU tune algorithm to match host.
  * Added optional gain behavior where TIA/IAMP gain elements are
    removed from available gain range.
  * Improved spurious USB transfer handling.
  LimeSuiteGUI:
  * Fixed an issue of file close not being called in FFTviewer.
  * Fixed compilation for wxWidgets STL.
  SoapyLMS:
  * Updated linkFormat stream option so it changes link format
    in LimeSuite library.
  Other changes:
  * Added LimeSuite library information to QuickTest.
  * Added CMake option to enable optional gain behavior.
- Drop patch (included upstream):
  * 0001-Allow-compilation-with-wxWidgets-STL-build.patch
* Sun Sep  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use wxGTK3 instead of wxWidgets (GTK2), allow building with
  STL variant:
  * 0001-Allow-compilation-with-wxWidgets-STL-build.patch
- Remove irrelevant dependencies: i2c-tools, sqlite3
* Thu Aug  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.07.2
  - Updated CMake to automatically include atomic library when
    needed.
  - Updated CMake to include required thread libraries on different
    systems.
  - Added missing changelog entries and version information
* Fri Jul 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.07.1
  LimeSuite library changes:
  * Changed LimeSDR-Mini SXR default values to match SXT
  * Fix for lms chip id not changing when setting interface
    frequency
  * Improve SXT/SXR tune in MCU calibrations
  * Set stream FIFO size to be at least 4 packets
  * Increased availble COM port values for LimeRFE board
  * Added unicode check when LimeRFE COM port is being opened
  LimeSuiteGUI:
  * Fixed display of CLKGEN values
  * Changed numeric slider settings for better fit on some
    distributions
  * Changed power meter to always be visible in LimeRFE panel
  * Changed LimeRFE panel's info to be read only
  * Added clear button to LimeRFE info panel
  * Fixed GUI freezing when opening LimeRFE board through SDR
    connection with flipped cable
  SoapyLMS:
  * Return actual supported sample rates instead of returning
    static limits
  Octave:
  * Fixed warnings when loading LimeSuite library
  Other changes:
  * Updated CMake so that LimeRFE module is optional
  * Added HW, GW version and temperature information to QuickTest
    output
  * Fixed LimeUtil loading wrong device with optional arguments
- Remove patch (not longer needed):
  * 0001-Remove-some-warnings-LimeRFE-related.patch
* Wed Jan 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.01.0
  LimeSuite library changes:
  * Including LimeRFE support
  * Update CGEN calculation to allow lower CGEN values
  * Configure RF switches (when possible) to avoid transmission
    during calibration
  * Automatically reconfigure GFIR LPF after sample rate change
  * Remove LMS_EnableCalibCache function from LimeSuite.h
  * Improve PLL locking in calibration procedures
  * Fix Tx transfer size being set to Rx transfer size
  * Fix RF path being auto-set after it was selected explicitly
    for LimeSDR-Mini
  * Add option to perform Rx phase alignment instead of of always
    running it
  * Improve SXT/SXR tune by automatically retrying with higher
    bias current setting
  * Update FIFO buffers to use memory more efficiently
  SoapyLMS:
  * Add oversampling setting
  * Set bandwidth to sample rate if bandwidth is not explicitly set
  * Fix possible segfault when 2 Rx cahnnels are used
  * Pause streaming when changing sample rate
  * Return time error when negative timestmp is used
  * Automatically use wide enough bandwidth setting for RF
    frequencies bellow 30 MHz
  * Remove master clock setting
  * Add setting descriptions
  * Implement read for setting advertised by getSettingInfo()
  LimeSuiteGUI:
  * Add panel for LMS API function testing
  * Add option to play WFM file from software
  * fix channel measurement in FFTviewer for Ch.B in MIMO mode
  Octave plugin:
  * Add LimeGetStreamStatus function
  * Add LimeTransceiveSamples function
  * Update antenna selection after loading ini file
  Other changes:
  * Fix LimeQuickTest not outputing to windows command line
- Add patch:
  * 0001-Remove-some-warnings-LimeRFE-related.patch
* Mon May 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 19.04.0
  LimeSuite library changes:
  * Added support for LimeNet-Micro v2.1
  * Fixed Tx ch.B calibration when Rx ch.B is disabled
  * Added save and restore of analog DC/IQ calibration values when
    saving/loading INI file
  * Fixed Rx only mode not working on LimeSDR-USB with sample
    rate <2.5 MSps
  * Fixed Rx only mode not working on LimeSDR-USB with sample
    rate <2.5 MSps
  * change coefficents in LMS7002M::GetTemperature() to approximately
    match actual temperature
  LimeSuiteGUI:
  - Updated "Board controls" panel for LimeNet-Micro
  Other changes
  - Added LimeNET-Micro support to LimeQuickTest
  - LimeSDR-USB v1.4 updated to r2.21 gateware
  - LimeSDR-Mini updated to r1.30 gateware
* Thu Mar  7 2019 Martin Hauke <mardnh@gmx.de>
- Upate to version 19.01.0
  LimeSuite library changes:
  * Allow filtering devices by partial serial number
  * Add GPIO control for LimeSDR-Mini
  * Change LMS_VCTCXOWrite() to save value to non-volatile storage
  * Change LMS_VCTCXORead() to read value from non-volatile storage
  * Make some improvements in GFIR setup
  * Fix Tx not working when Rx is disabled on LimeSDR-Mini
  * Add initial support for LimeNET-Micro
  * Add auto RF path selection option (LMS_PATH_AUTO) for
    LMS_SetAntenna()
  * Remove LMS_Disconnect() and LMS_IsOpen() functions from API
  * Add support for sending smaller Tx packets (improve end of
    burst handling)
  * Change Rx RF path set by LMS_Init() for LimeSDR-USB to LNA_L
  * Disable Tx channel in LMS_Init()
  LimeSuiteGUI:
  * Add GPIO controls to "Board controls" panel for LimeSDR-Mini
  * Add option to "Board controls" panel to write VCTCXO value to
    non-volatile storage
  SoapyLMS:
  * Update to soapysdr0.7 module ABI
  * add manual DC/IQ calibrations
  Other changes:
  * LimeUtil: fix LimeSDR-Mini not exiting programming mode after
    flashing FPGA
  * LimeQuickTest: test 1st board when multiple boards are detected
    (instead of exiting)
  * Add Octave plugin to CMake build
  * Add log handler to Octave plugin
  * Add IQ/DC calibration to basicTX example
  * LimeSDR-USB v1.4 updated to r2.20 gateware
  * LimeSDR-Mini updated to r1.29 gateware
* Sat Nov 10 2018 mardnh@gmx.de
- Update soapy-module version 0.6 -> 0.7
* Fri Oct  5 2018 mardnh@gmx.de
- Upate to version 18.10.0
  LimeSuite library changes:
  * Fix CalibrateTxGain() XBUF settings for 3rd party boards
  * Add interpolation/decimation support for SISODDR mode
  * Always use SISODDR mode for LimeSDR-Mini
  * Fix Rx filter calibration for 2nd channel with low bandwidth
    values
  * Fix index lookup for opt_gain_tbb cache (ChB out of bounds)
  * Add SXT/SXR VCO cache
  * Add FPGA register cache
  * Add connection remote (disabled by default)
  * Fix incorrect TBB gain control behaviour under certain
    conditions
  * Disable GFIR coefficient ordering based on oversampling when
    coefficient count is to high
  * Remove late timestamp reset commands from Rx streaming loop
  LimeSuiteGUI:
  * Update board controls panel
  * Add LPF coefficient calculation controls for GFIRs to TxTSP
    and RxTSP tabs
  Other changes:
  * LimeSDR-USB v1.4 updated to r2.18 gateware
  * LimeSDR-Mini updated to r1.27 gateware
  * Add Tx only LMS API example
  * SoapyLMS: remove stream activity checks
* Wed Jun 13 2018 mardnh@gmx.de
- Update to version 18.06.0
  LimeSuite library changes:
  * Fixed zero filled packet transmitted on Tx FIFO timeout
  * Fixed LMS_GetFrequency() to return correct frequency in TDD mode
  * Added HBD/HBI bypass mode for LimeSDR-USB
  * Made automatic Tx gain calibrations less frequent
  * Fixed some issues with GFIR usage
  * Some fixes for LimeSDR-QPCIe
  SoapyLMS changes:
  * Fixed writeSetting to not throw every time
  * Added 'skipCal' stream argument to disable calibration
  * Added 'CALIBRATE' setting for writeSetting()
  Other changes:
  * Added LimeSDR-USB support to LimeQuickTest
  * Added sample format and Tx sync selection to FFTviewer
  * Fix LimeSuiteConfig for debian packages
  * LimeSDR-USB v1.4 updated to r2.17 gateware
  * LimeSDR-Mini v1.1 updated to r1.25 gateware
* Thu Apr 19 2018 mardnh@gmx.de
- Update to version 18.04.1
  * Add multiple device support for LimeSDR-Mini
  * Add QuickTest Utility for LimeSDR-Mini
  * Remove calibration cache database
  * LimeSuiteGUI: Remove duplicate information from 'Device Info' panel
- Remove patch:
  * limesuite-fix-cmake-path.patch (fixed upstream)
* Mon Apr  9 2018 mpluskal@suse.com
- Cleanup with spec-cleaner
* Fri Apr  6 2018 mardnh@gmx.de
- Update to version 18.04.0
  * Fixed Tx filter calibration
  * Fixed FPGA PLL configuration when B channel is disabled
  * Fixed non-working controls in LimeSuiteGUI 'TRX Gain' tab
  * Changed CGEN VCO tune algorithm
  * LimeSDR-USB v1.4 updated to r2.16 gateware
- Add patch:
  * limesuite-fix-cmake-path.patch
- Update to version 18.03.0
  SoapyLMS changes:
  * Do not tune NCO when LO is within tuning range
  * Filter BW reported to match filtersCalibration
  * Function implementations changed to use same code as LMS API
  LimeSuiteGUI changes:
  * Added log levels
  * Added additional controls to SPI panel
  * Reduced number of programming modes in Programming panel
  LimeSuite library changes:
  * Added LimeSDR-Mini programming
  * Changed default settings for LimeSDR-Mini
  * Updated calibrations
  * Add phase alignment for dual channel configuration
  * Updated FPGA PLL configuration
  * Fix B channel only streaming
  * Fixed LMS7002M::GetPathRFE for LNAH case
  * Fixed CGEN not tuning to 484-487 MHz
  LMS API changes:
  * LMS_Open() can no longer succeed without connecting to hardware
  * LMS_Disconnect() and LMS_IsOpen() are now deprecated because of above change
  * Changed firmware/gateware programming functions
  * Changed lms_dev_info_t structure
  * LMS_SetLOFrequency() now attempts to set different frequencies for A/B channels using NCO
  * Fix Rx NCO direction flip (downconvert flag used to set Rx NCO to upconvert)
  * Disabling LPF is now same as setting it to maximum bandwidth
  * Extented gain range for LMS_SetGaindB()
  Other changes:
  * Reduce SIMD flags when packaging for x86
  * LimeSDR-USB v1.4 updated to r2.15 gateware
  * LimeSDR-Mini v1.1 updated to r1.24 gateware
- Add limesuite-fix-cmake-path.patch
* Tue Dec 19 2017 mardnh@gmx.de
- Update to version 17.12.0
  SoapyLMS changes:
  * Force MIMO alignment
  * Add TBB frontend gain configuration
  * Fix/adjust gain ranges
  LMS API changes:
  * Increased USB timeouts
  * Updated FTDI library (LimeSDR-Mini on Windows)
  * RF switch control for LimeSDR-Mini
  * Updated setup/destruction of streams
  * various bug fixes
  LimeSuiteGUI changes:
  * Update LimeSDR-Mini panel
* Sun Nov  5 2017 jengelh@inai.de
- Update descriptions.
* Sat Oct 21 2017 mardnh@gmx.de
- Use SSE-SIMD-FLAGS only on x86_64 machines
* Thu Oct 19 2017 mardnh@gmx.de
- Update to version 17.10.0
  SoapyLMS changes:
  * Initial support for LimeSDR-Mini
  * Disable calibration cache by default
  LMS API changes:
  * Initial support for LimeSDR-Mini
  LimeSuiteGUI changes:
  * Added scrollbars
  * Fix multiple crashes that occured when board is not connected
  * Bring window to front when trying to open already opened window
  * Some cosmetic GUI changes
  * Added default config button to GUI
  Other changes:
  * LimeSDR v1.4 updated to r2.11 gateware
- Build with -DENABLE_SIMD_FLAGS="SSE4.2" to avoid the new default
  optimization settings "-mmarch=native" otherwise it the binaries
  are expected to crash on machines different from the build hosts.
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 17.09.1
  SoapyLMS changes:
  - SoapyLMS7 caches stream enable and disables on close
  - Fixed late packet reporting in SoapyLMS7 stream status
  LMS API changes:
  - Added simple GPIO example utilizing functions from LimeSuite.h
  - Fixed WriteStream() end of burst flushing in fifo.h
  - Fixed abs() overload compiler issue in lms7_device.cpp
  - Removed private include in mcu_program/host_src/main.cpp
  - Fixed error checking bug causing compilation error on MacOS in
    LMS_GetGaindB() and LMS_GetNormalizedGain()
  Other changes:
  - LimeSDR v1.4 updated to r2.10 gateware
- Update to version 17.09.0
  LimeSuite library changes:
  - Added transfer size adjustment based on sample rate
  - Improved MCU calibration procedures
  - Initial support for LimeSDR-QPCIe
  - Changed format to 16 bit for data transfer when float (non-native) format
    is selected in API
  LMS API changes:
  - Added external reference clock(LMS_CLOCK_EXTREF) configuration to
    LMS_SetClockFreq()
  - Change LMS_SetGaindB() and LMS_SetNormalizedGain() to select optimal
    TBB gain for TX
  - Fixed LMS_GetStreamStatus() not returning some status values
  LimeSuiteGUI changes:
  - Unified read/write params in board controls panel
  - Fixed some GUI fields not updating correctly/reporting wrong values
  Other changes:
  - LimeSDR v1.4 updated to r2.9 gateware
  - Added LMS API doxygen generation to CMake
  - Added CMake option to enable compiler SIMD flags
* Wed Jun 21 2017 mardnh@gmx.de
- Update to version 17.06.0
  API additions:
  - LMS_GPIODirRead
  - LMS_GPIODirWrite
  - LMS_CalibrateInternalADC
  - LMS_CalibrateAnalogRSSIDC
  - LMS_CalibrateRP_BIAS
  - LMS_CalibrateTxGain
  - LMS_SetClockFreqWithSpurCancelation
  General changes:
  - SoapyLMS7 - added getMasterClockRates()
  - SoapyLMS7 - added getSampleRateRange()
  - LimeSDR v1.4 updated to r2.8 gateware
  - GPIO support in SoapyLM7 module
  - Library level logging support
  - Speed up x640,x641 spi
  - FFTviewer: add checkbox for RX->TX loopback control
  - Merged major MCU based calibrations update
* Fri May  5 2017 mardnh@gmx.de
- Update soapy-module version 0.5-2 -> 0.6
* Wed May  3 2017 mardnh@gmx.de
- Update to version 17.02.2
  - Fixed register typo in LMS7002M::SetTxDCOffset()
  - Added option defaults for stream args in SoapyLMS7
  - Fixed LMS7002M::GetPathRFE() currently selected path
* Wed Apr 19 2017 mardnh@gmx.de
- initial package, version 17.02.1
